// java wrapper for vtkRenderPassCollection object
//

package vtk;
import vtk.*;

public class vtkRenderPassCollection extends vtkCollection
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddItem_2(vtkRenderPass id0);
  public void AddItem(vtkRenderPass id0)
    { AddItem_2(id0); }

  private native long GetNextRenderPass_3();
  public vtkRenderPass GetNextRenderPass() {
    long temp = GetNextRenderPass_3();

    if (temp == 0) return null;
    return (vtkRenderPass)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetLastRenderPass_4();
  public vtkRenderPass GetLastRenderPass() {
    long temp = GetLastRenderPass_4();

    if (temp == 0) return null;
    return (vtkRenderPass)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkRenderPassCollection() { super(); }

  public vtkRenderPassCollection(long id) { super(id); }
  public native long   VTKInit();

}
